@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Copyright (c) 2015 Tim Savannah under LGPLv3. See LICENSE (https://gnu.org/licenses/lgpl-3.0.txt) for more information.
+# Copyright (c) 2015, 2016 Tim Savannah under LGPLv3. See LICENSE (https://gnu.org/licenses/lgpl-3.0.txt) for more information.
 #
 #   Parser implementation
 
@@ -296,7 +296,7 @@ class AdvancedHTMLParser(HTMLParser):
 
         elements = []
 
-        if isFromRoot is True and root.get(attrName) == attrValue:
+        if isFromRoot is True and root.getAttribute(attrName) == attrValue:
             elements.append(root)
 
         for child in root.children:
@@ -422,7 +422,10 @@ class AdvancedHTMLParser(HTMLParser):
                 @param html <str> - valid HTML
         '''
         self.reset()
-        self.feed(html)
+        if isinstance(html, bytes):
+            self.feed(html.decode(self.encoding))
+        else:
+            self.feed(html)
 
 class IndexedAdvancedHTMLParser(AdvancedHTMLParser):
     '''
